@@ -25,6 +25,7 @@ class EmploymentContract(BaseModel):
     monthly_salary: int = Field(..., alias="monthly-salary")
     employment_start_date: date = Field(..., alias="employment-start-date")
     manager_user: dict = Field(None, alias="manager-user")
+    monthly_salary_start_date: date = Field(None, alias="monthly-salary-start-date")
 
 
 class PeUser(BaseModel):
@@ -70,8 +71,9 @@ class PeUser(BaseModel):
 
     @property
     def days_to_birthday(self) -> int:
-        return (self.next_birthday() - date.today()).days
+        return (self.next_birthday - date.today()).days
 
+    @property
     def next_birthday(self) -> date:
         now = date.today()
         next_birthday = datetime.strptime(self.contract.ssn.split("-")[0], "%Y%m%d").replace(year=now.year).date()
@@ -80,8 +82,13 @@ class PeUser(BaseModel):
             next_birthday = next_birthday.replace(year=now.year + 1)
         return next_birthday
 
+    @property
     def years_next_birthday(self) -> int:
-        return self.next_birthday().year - datetime.strptime(self.contract.ssn.split("-")[0], "%Y%m%d").year
+        return self.next_birthday.year - datetime.strptime(self.contract.ssn.split("-")[0], "%Y%m%d").year
+
+    @property
+    def latest_salary_revision(self) -> date:
+        return self.contract.monthly_salary_start_date
 
     def __str__(self):
         return f"{self.name} ({self.email})"
@@ -135,6 +142,12 @@ class PeUser(BaseModel):
             i += 1
 
 if __name__ == "__main__":
-    creds = PeCredentials(company_id="1212", api_access_token="123asdfwer")
-    PeUser.pe_credentials = creds
-    PeUser.all_users()
+    import os
+    from pprint import pprint
+    credentials = PeCredentials(company_id=os.getenv("COMPANY"), api_access_token=os.getenv("API"))
+    PeUser.pe_credentials = credentials
+    for user in PeUser.all_users():
+        print()
+        print(user.name)
+        pprint(user.latest_salary_revision)
+        # pprint(user.dict())
